@@ -21,6 +21,22 @@ import nfldb.team
 __pdoc__ = {}
 
 
+def select_columns(tabtype, prefix=None):
+    """
+    Return a valid SQL SELECT string for the given table type. If
+    `prefix` is not `None`, then it will be used as a prefix for each
+    SQL field.
+
+    This function includes derived fields in `tabtype`.
+
+    This should only be used if you're writing SQL queries by hand.
+    """
+    sql = lambda f: tabtype._as_sql(f, prefix=prefix)
+    select = [sql(f) for f in tabtype._sql_columns]
+    select += ['%s AS %s' % (sql(f), f) for f in tabtype._sql_derived]
+    return ', '.join(select)
+
+
 def _stat_categories():
     """
     Returns a `collections.OrderedDict` of all statistical categories
@@ -131,20 +147,6 @@ def _as_row(fields, obj):
     return [(f, getattr(obj, f, None)) for f in fields if f not in exclude]
 
 
-def _select_fields(tabtype, prefix=None):
-    """
-    Return a valid SQL SELECT string for the given table type. If
-    `prefix` is not `None`, then it will be used as a prefix for each
-    SQL field.
-
-    This function includes derived fields in `tabtype`.
-    """
-    sql = lambda f: tabtype._as_sql(f, prefix=prefix)
-    select = [sql(f) for f in tabtype._sql_columns]
-    select += ['%s AS %s' % (sql(f), f) for f in tabtype._sql_derived]
-    return ', '.join(select)
-
-
 def _sum_fields(tabtype, prefix=None):
     """
     Return a valid SQL SELECT string for an aggregate query. This
@@ -271,7 +273,7 @@ class Enums (object):
                        ['Pregame', 'Q1', 'Q2', 'Half',
                         'Q3', 'Q4', 'OT', 'OT2', 'Final'])
     """
-    Represents the phase of the game. e.g., `Q1` or `HALF`.
+    Represents the phase of the game. e.g., `Q1` or `Half`.
     """
 
     season_phase = _Enum('season_phase',
@@ -546,8 +548,11 @@ class FieldPosition (object):
 
         For example, `OPP 19` corresponds to an offset of `31`
         and `OWN 5` corresponds to an offset of `-45`. Midfield can be
-        expressed as either `OWN 0` or `OPP 0`.
+        expressed as either `MIDFIELD`, `OWN 50` or `OPP 50`.
         """
+        if pos.upper() == 'MIDFIELD':
+            return FieldPosition(0)
+
         field, yrdline = pos.split(' ')
         field, yrdline = field.upper(), int(yrdline)
         assert field in ('OWN', 'OPP')
@@ -569,7 +574,7 @@ class FieldPosition (object):
         assert -50 <= offset <= 50
         self._offset = offset
 
-    def add_yards(self, yards):
+    def _add_yards(self, yards):
         """
         Returns a new `nfldb.FieldPosition` with `yards` added to this
         field position. The value of `yards` may be negative.
@@ -589,6 +594,14 @@ class FieldPosition (object):
         """
         return self._offset is not None
 
+    def __add__(self, other):
+        if isinstance(other, FieldPosition):
+            toadd = other._offset
+        else:
+            toadd = other
+        newoffset = max(-50, min(50, self._offset + toadd))
+        return FieldPosition(newoffset)
+
     def __lt__(self, other):
         if self.__class__ is not other.__class__:
             return NotImplemented
@@ -631,7 +644,7 @@ class PossessionTime (object):
     __slots__ = ['__seconds']
 
     @staticmethod
-    def clock(clock_str):
+    def from_str(clock_str):
         """
         Introduces a `nfldb.PossessionTime` object from a string
         formatted as clock time. For example, `2:00` corresponds to
@@ -953,7 +966,7 @@ class Player (object):
         with Tx(db) as cursor:
             cursor.execute('''
                 SELECT %s FROM player WHERE player_id = %s
-            ''' % (_select_fields(Player), '%s'), (player_id,))
+            ''' % (select_columns(Player), '%s'), (player_id,))
             if cursor.rowcount > 0:
                 return Player.from_row(db, cursor.fetchone())
         return None
@@ -1254,7 +1267,7 @@ class PlayPlayer (object):
         """
         if self._play is None:
             self._play = Play.from_id(self._db, self.gsis_id, self.drive_id,
-                                      self._play_id)
+                                      self.play_id)
         return self._play
 
     @property
@@ -1335,7 +1348,7 @@ class PlayPlayer (object):
     def __getattr__(self, k):
         if k in PlayPlayer.__slots__:
             return 0
-        raise AttributeError
+        raise AttributeError(k)
 
 
 class Play (object):
@@ -1470,7 +1483,7 @@ class Play (object):
         with Tx(db) as cursor:
             q = '''
                 SELECT %s FROM play WHERE (gsis_id, drive_id, play_id) = %s
-            ''' % (_select_fields(Play), '%s')
+            ''' % (select_columns(Play), '%s')
             cursor.execute(q, ((gsis_id, drive_id, play_id),))
             if cursor.rowcount > 0:
                 return Play.from_row(db, cursor.fetchone())
@@ -1589,7 +1602,7 @@ class Play (object):
                 q = '''
                     SELECT %s FROM play_player
                     WHERE (gsis_id, drive_id, play_id) = %s
-                ''' % (_select_fields(PlayPlayer), '%s')
+                ''' % (select_columns(PlayPlayer), '%s')
                 cursor.execute(
                     q, ((self.gsis_id, self.drive_id, self.play_id),))
                 for row in cursor.fetchall():
@@ -1734,7 +1747,7 @@ class Drive (object):
         with Tx(db) as cursor:
             cursor.execute('''
                 SELECT %s FROM drive WHERE (gsis_id, drive_id) = %s
-            ''' % (_select_fields(Drive), '%s'), ((gsis_id, drive_id),))
+            ''' % (select_columns(Drive), '%s'), ((gsis_id, drive_id),))
             if cursor.rowcount > 0:
                 return Drive.from_row(db, cursor.fetchone())
         return None
@@ -1848,7 +1861,8 @@ class Drive (object):
             with Tx(self._db) as cursor:
                 q = '''
                     SELECT %s FROM play WHERE (gsis_id, drive_id) = %s
-                ''' % (_select_fields(Play), '%s')
+                    ORDER BY time ASC, play_id ASC
+                ''' % (select_columns(Play), '%s')
                 cursor.execute(q, ((self.gsis_id, self.drive_id),))
                 for row in cursor.fetchall():
                     p = Play.from_row(self._db, row)
@@ -1900,7 +1914,7 @@ class Game (object):
     a quarterly breakdown of scores, turnovers, the time the game
     started, the season week the game occurred in, and more.
 
-    Each game corresponds to **zero or more** drive. A game usually
+    Each game corresponds to **zero or more** drives. A game usually
     corresponds to at least one drive, but if the game is active, there
     exist valid ephemeral states where a game has no drives.
     """
@@ -2027,7 +2041,8 @@ class Game (object):
         with Tx(db) as cursor:
             cursor.execute('''
                 SELECT %s FROM game WHERE gsis_id = %s
-            ''' % (_select_fields(Game), '%s'), (gsis_id,))
+                ORDER BY gsis_id ASC
+            ''' % (select_columns(Game), '%s'), (gsis_id,))
             if cursor.rowcount > 0:
                 return Game.from_row(db, cursor.fetchone())
         return None
@@ -2156,7 +2171,8 @@ class Game (object):
             with Tx(self._db) as cursor:
                 cursor.execute('''
                     SELECT %s FROM drive WHERE gsis_id = %s
-                ''' % (_select_fields(Drive), '%s'), (self.gsis_id,))
+                    ORDER BY start_time ASC, drive_id ASC
+                ''' % (select_columns(Drive), '%s'), (self.gsis_id,))
                 for row in cursor.fetchall():
                     d = Drive.from_row(self._db, row)
                     d._game = self
@@ -2171,7 +2187,7 @@ class Game (object):
         """
         plays = []
         for drive in self.drives:
-            for play in self.plays:
+            for play in drive.plays:
                 plays.append(play)
         return plays
 
